@@ -1,5 +1,4 @@
 import base64
-import logging
 import os
 import re
 from configparser import ConfigParser
@@ -15,11 +14,8 @@ from telegram.ext import CallbackContext, ConversationHandler
 config = ConfigParser()
 config.read('config.ini')
 
-logging.basicConfig(format='%(asctime)s - %(name)s - %(levelname)s - %(message)s',
-                    level=logging.INFO)
-
-logger = logging.getLogger(__name__)
-
+import logging
+logger = logging.getLogger()
 
 class callback_query_handler():
     def __init__(self, actions_dict):
@@ -165,9 +161,9 @@ class Action():
 
                 text = item["text"]
                 
-                logger.debug("type: ", type(update))
-                logger.debug("update: ", update)
-                logger.debug("context: ", str(context.user_data))
+                logger.debug("type: {}".format(type(update)))
+                logger.debug("update: {}".format(str(update)))
+                logger.debug("context: {}".format(str(context.user_data)))
                 if type(update) == CallbackQuery:
                     update.from_user.send_message(text.format(
                         **context.user_data), reply_markup=reply_markup, parse_mode=parse_mode, disable_web_page_preview=disable_web_page_preview)
