@@ -1,6 +1,5 @@
 
 from collections import defaultdict
-from digitalguide.pattern import JAHRESZAHL_PATTERN, KOMMAZAHL_PATTERN
 from digitalguide.standardinteraktion.Action import readActions
 from digitalguide.standardinteraktion.Trigger import readTriggers
 
@@ -115,27 +114,31 @@ class Interaktion:
                 interaktion_dict["Tipp"], messanger=messanger, asset_url=asset_url)
 
             if interaktion_dict["Typ"][0][0] == "Jahreszahl":
-                states["{}_FRAGE".format(poi_name.upper())] = (readTriggers([("Regex", JAHRESZAHL_PATTERN)], "{}_aufloesung".format(poi_name))) \
+                states["{}_FRAGE".format(poi_name.upper())] = (readTriggers([("Regex", "JAHRESZAHL_PATTERN")], "{}_aufloesung".format(poi_name))) \
                     + [{"handler": "TypeHandler", "type": "Update",
                         "action": "{}_tipp".format(poi_name)}]
 
             elif interaktion_dict["Typ"][0][0] == "Prozentzahl":
-                states["{}_FRAGE".format(poi_name.upper())] = (readTriggers([("Regex", KOMMAZAHL_PATTERN)], "{}_aufloesung".format(poi_name))) \
+                states["{}_FRAGE".format(poi_name.upper())] = (readTriggers([("Regex", "KOMMAZAHL_PATTERN")], "{}_aufloesung".format(poi_name))) \
+                    + readTriggers([("Liste", "Weiter")], "{}_aufloesung".format(poi_name)) \
                     + [{"handler": "TypeHandler", "type": "Update",
                         "action": "{}_tipp".format(poi_name)}]
 
             elif interaktion_dict["Typ"][0][0] == "Kommazahl":
-                states["{}_FRAGE".format(poi_name.upper())] = (readTriggers([("Regex", KOMMAZAHL_PATTERN)], "{}_aufloesung".format(poi_name))) \
+                states["{}_FRAGE".format(poi_name.upper())] = (readTriggers([("Regex", "KOMMAZAHL_PATTERN")], "{}_aufloesung".format(poi_name))) \
+                    + readTriggers([("Liste", "Weiter")], "{}_aufloesung".format(poi_name)) \
                     + [{"handler": "TypeHandler", "type": "Update",
                         "action": "{}_tipp".format(poi_name)}]
 
             elif interaktion_dict["Typ"][0][0] == "Länge":
-                states["{}_FRAGE".format(poi_name.upper())] = (readTriggers([("Regex", KOMMAZAHL_PATTERN)], "{}_aufloesung".format(poi_name))) \
+                states["{}_FRAGE".format(poi_name.upper())] = (readTriggers([("Regex", "KOMMAZAHL_PATTERN")], "{}_aufloesung".format(poi_name))) \
+                    + readTriggers([("Liste", "Weiter")], "{}_aufloesung".format(poi_name)) \
                     + [{"handler": "TypeHandler", "type": "Update",
                         "action": "{}_tipp".format(poi_name)}]
 
             elif interaktion_dict["Typ"][0][0] == "Römische Jahreszahl":
                 states["{}_FRAGE".format(poi_name.upper())] = (readTriggers([("Regex", "^M{0,3}(CM|CD|D?C{0,3})(XC|XL|L?X{0,3})(IX|IV|V?I{0,3})$")], "{}_aufloesung".format(poi_name))) \
+                    + readTriggers([("Liste", "Weiter")], "{}_aufloesung".format(poi_name)) \
                     + [{"handler": "TypeHandler", "type": "Update",
                         "action": "{}_tipp".format(poi_name)}]
 
@@ -151,10 +154,23 @@ class Interaktion:
                 interaktion_dict["Frage"] + [("Return", "{}_FRAGE".format(poi_name.upper()))], messanger=messanger, asset_url=asset_url)
 
             answer_id_name_list = []
+            answer_id_list = []
+            for aktion, aktion_list in interaktion_dict.items():
+                if aktion.startswith("name_"):
+                    answer_id_name_list.append(
+                        [aktion.replace("name_", ""), aktion_list[0][1]])
+                    answer_id_list.append(
+                        aktion.replace("name_", ""))
+
             for aktion, aktion_list in interaktion_dict.items():
                 if aktion.startswith("antwort_"):
-                    actions["{}_{}".format(poi_name, aktion)] = readActions([("Formel", "function: check_in_context\nkey: {}\nvalue: {}\ndoppelte_antwort: {}\n".format(poi_name, aktion.replace("antwort_", ""), interaktion_dict["doppelte Antwort"][0][1]))], messanger=messanger, asset_url=asset_url)\
-                        + readActions([("Formel", "function: append_to_context\nkey: {}\nvalue: {}".format(poi_name, aktion.replace("antwort_", "")))], messanger=messanger, asset_url=asset_url)\
+                    actions["{}_{}".format(poi_name, aktion)] = [{"type": "function",
+                                                                  "func": "loop_list",
+                                                                  "key": poi_name,
+                                                                  "value": aktion.replace("antwort_", ""),
+                                                                  "doppelte_antwort": interaktion_dict["doppelte Antwort"][0][1],
+                                                                  "answer_id_list": answer_id_list,
+                                                                  "fertig_antwort": interaktion_dict["fertig Antwort"][0][1]}]\
                         + readActions(aktion_list, messanger=messanger, asset_url=asset_url) \
                         + readActions(interaktion_dict["richtig Antwort"], messanger=messanger, asset_url=asset_url)
                     
@@ -168,10 +184,6 @@ class Interaktion:
                     states["{}_AUFLOESUNG".format(poi_name.upper())] += readTriggers(
                         aktion_list, "{}_{}_re".format(poi_name, aktion.replace("trigger_", "antwort_")))
 
-                elif aktion.startswith("name_"):
-                    answer_id_name_list.append(
-                        [aktion.replace("name_", ""), aktion_list[0][1]])
-
             actions["{}_aufloesung".format(poi_name)] = [{"type": "function", "func": "eval_list", "answer_id_name_list": answer_id_name_list, "poi": poi_name, "response_text": interaktion_dict["response_text"][0][1]}]\
                 + readActions(interaktion_dict["Aufloesung"], messanger=messanger, asset_url=asset_url) \
                 + readActions([("Return", "{}_AUFLOESUNG".format(poi_name.upper()))], messanger=messanger, asset_url=asset_url)
