@@ -12,7 +12,7 @@ config = ConfigParser()
 config.read("config.ini")
 
 session = boto3.session.Session()
-client = session.client('s3',
+s3_client = session.client('s3',
                         region_name=config["space"]["region_name"],
                         endpoint_url=config["space"]["endpoint_url"],
                         aws_access_key_id=os.getenv('SPACES_KEY'),
@@ -23,10 +23,10 @@ def telegram_write_photo(update, context, bucket, folder):
     user_id = update.effective_user.id
     name = update.effective_user.name
 
-    client.put_object(Bucket=bucket,
+    s3_client.put_object(Bucket=bucket,
                       Key=folder + "/" +
                       str(datetime.now())+"_" +
-                      str(user_id) + "_" + name + '.jpg',
+                      str(user_id) + '.jpg',
                       Body=update.message.photo[-1].get_file(
                       ).download_as_bytearray(),
                       ACL='private',
@@ -41,10 +41,10 @@ def whatsapp_write_photo(client, update: WhatsAppUpdate, context, bucket, folder
     name = update.ProfileName
     update.MediaUrl0
 
-    client.put_object(Bucket=bucket,
+    s3_client.put_object(Bucket=bucket,
                       Key=folder + "/" +
                       str(datetime.now())+"_" +
-                      str(user_id) + "_" + name + '.jpg',
+                      str(user_id) + '.jpg',
                       Body=requests.get(update.MediaUrl0,
                                         allow_redirects=True).content,
                       ACL='private',
@@ -59,10 +59,10 @@ def telegram_write_message(update, context, bucket, folder):
     name = update.effective_user.name
     message = update.effective_message.text
 
-    client.put_object(Bucket=bucket,
+    s3_client.put_object(Bucket=bucket,
                       Key=folder + "/" +
                       str(datetime.now())+"_" +
-                      str(user_id) + "_" + name + '.txt',
+                      str(user_id) + '.txt',
                       Body=message,
                       ACL='private',
                       # Metadata={
@@ -70,28 +70,31 @@ def telegram_write_message(update, context, bucket, folder):
                       # }
                       )
 
+
 def whatsapp_write_message(client, update: WhatsAppUpdate, context, bucket, folder):
     user_id = update.WaId
     name = update.ProfileName
     message = update.Body
 
-    client.put_object(Bucket=bucket,
-                      Key= folder + "/" + str(datetime.now())+"_"+str(user_id) + "_" + name + '.txt',
+    s3_client.put_object(Bucket=bucket,
+                      Key=folder + "/" +
+                      str(datetime.now())+"_"+str(user_id) + '.txt',
                       Body=message,
                       ACL='private',
-                      #Metadata={
+                      # Metadata={
                       #    'x-amz-meta-my-key': 'your-value'
-                      #}
+                      # }
                       )
 
+
 def telegram_write_voice(update, context, bucket, folder):
     user_id = update.effective_user.id
     name = update.effective_user.name
 
-    client.put_object(Bucket=bucket,
+    s3_client.put_object(Bucket=bucket,
                       Key=folder + "/" +
                       str(datetime.now())+"_" +
-                      str(user_id) + "_" + name + '.mp3',
+                      str(user_id) + '.mp3',
                       Body=update.message.voice.get_file().download_as_bytearray(),
                       ACL='private',
                       # Metadata={
@@ -99,18 +102,21 @@ def telegram_write_voice(update, context, bucket, folder):
                       # }
                       )
 
+
 def whatsapp_write_voice(client, update: WhatsAppUpdate, context, bucket, folder):
     user_id = update.WaId
     name = update.ProfileName
 
-    client.put_object(Bucket=bucket,
-                    Key= folder + "/" + str(datetime.now())+"_"+str(user_id) + "_" + name + '.mp3',
-                    Body=requests.get(update.MediaUrl0, allow_redirects=True).content,
-                    ACL='private',
-                    #Metadata={
-                    #    'x-amz-meta-my-key': 'your-value'
-                    #}
-                    )
+    s3_client.put_object(Bucket=bucket,
+                      Key=folder + "/" +
+                      str(datetime.now())+"_"+str(user_id) + '.mp3',
+                      Body=requests.get(update.MediaUrl0,
+                                        allow_redirects=True).content,
+                      ACL='private',
+                      # Metadata={
+                      #    'x-amz-meta-my-key': 'your-value'
+                      # }
+                      )
 
 
 def telegram_write(update, context, bucket, folder):
@@ -125,12 +131,13 @@ def telegram_write(update, context, bucket, folder):
     else:
         raise NotImplementedError("This type of update can not be saved")
 
+
 def whatsapp_write(client, update: WhatsAppUpdate, context, bucket, folder):
     if update.MediaContentType0 and update.MediaContentType0.startswith("audio"):
         whatsapp_write_voice(client, update, context, bucket, folder)
     elif update.MediaContentType0 and update.MediaContentType0.startswith("image"):
         whatsapp_write_photo(client, update, context, bucket, folder)
-    elif update.Body!= "":
+    elif update.Body != "":
         whatsapp_write_message(client, update, context, bucket, folder)
     else:
         raise NotImplementedError("This type of update can not be saved")
